Momoko — Momoko 0.5.0 documentation

### Navigation

- Momoko 0.5.0 documentation »
- index
- / modules
- / next

# Momoko

An asynchronous Psycopg2 wrapper for Tornado.

Momoko makes use of the asynchronous support in Psycopg2, Tornado’s IOLoop to provide asynchronous queries in callback and blocking style. Downloads can be found at PyPi and the lastest source code at Github.

- News/Changelog
- Installation
- Examples
- API

## Indices and tables

- Index
- Module Index
- Search Page

}